@@ -3,7 +3,7 @@ package Sah::Schema::perl::distname_with_ver;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl distribution name with version number suffix, e.g. Foo-Bar@0.001',
@@ -57,7 +57,7 @@ Sah::Schema::perl::distname_with_ver - Perl distribution name with version numbe
 
 =head1 VERSION
 
-This document describes version 0.029 of Sah::Schema::perl::distname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
+This document describes version 0.030 of Sah::Schema::perl::distname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -93,21 +93,21 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # INVALID
+ "Foo-Bar"  # INVALID
 
- undef  # INVALID
+ "Foo::Bar"  # INVALID
 
- undef  # valid
+ "Foo-Bar\@1.0.0"  # valid
 
- undef  # valid
+ "Foo::Bar\@1.0.0"  # valid, becomes "Foo-Bar\@1.0.0"
 
- undef  # valid
+ "Foo-Bar\@0.5_001"  # valid
 
- undef  # valid
+ "Foo::Bar\@0.5_001"  # valid, becomes "Foo-Bar\@0.5_001"
 
- undef  # INVALID
+ "Foo-Bar\@a"  # INVALID
 
 =head1 DESCRIPTION
 
