@@ -3,7 +3,7 @@ package Sah::Schema::perl::modname;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module name, e.g. Foo::Bar',
@@ -49,7 +49,7 @@ Sah::Schema::perl::modname - Perl module name, e.g. Foo::Bar
 
 =head1 VERSION
 
-This document describes version 0.029 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
+This document describes version 0.030 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -63,7 +63,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -85,19 +85,19 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # valid
+ "Foo::Bar"  # valid
 
- undef  # valid
+ "Foo-Bar"  # valid, becomes "Foo::Bar"
 
- undef  # valid
+ "Foo/Bar"  # valid, becomes "Foo::Bar"
 
- undef  # valid
+ "Foo/Bar.pm"  # valid, becomes "Foo::Bar"
 
- undef  # valid
+ "Foo.Bar"  # valid, becomes "Foo::Bar"
 
- undef  # INVALID
+ "Foo|Bar"  # INVALID
 
 =head1 DESCRIPTION
 
