@@ -3,7 +3,7 @@ package Sah::Schema::perl::modprefix;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module prefix, e.g. Foo::Bar::',
@@ -61,7 +61,7 @@ Sah::Schema::perl::modprefix - Perl module prefix, e.g. Foo::Bar::
 
 =head1 VERSION
 
-This document describes version 0.029 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
+This document describes version 0.030 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -75,7 +75,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -97,23 +97,23 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # valid
+ ""  # valid
 
- undef  # INVALID
+ "::"  # INVALID
 
- undef  # valid
+ "Foo::"  # valid
 
- undef  # valid
+ "Foo::Bar"  # valid, becomes "Foo::Bar::"
 
- undef  # valid
+ "Foo::Bar::"  # valid
 
- undef  # INVALID
+ "::Foo"  # INVALID
 
- undef  # valid
+ "Foo"  # valid, becomes "Foo::"
 
- undef  # valid
+ "Foo/"  # valid, becomes "Foo::"
 
- undef  # valid
+ "Foo-"  # valid, becomes "Foo::"
 
 =head1 DESCRIPTION
 
