@@ -3,10 +3,10 @@ package Sah::Schema::perl::pm_filename;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-08'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.029'; # VERSION
+our $VERSION = '0.030'; # VERSION
 
 our $schema = [str => {
-    summary => 'Filename of perl module, e.g. /path/Foo.pm',
+    summary => 'A .pm filename, e.g. /path/Foo.pm',
     description => <<'_',
 
 Use this schema if you want to accept a filesystem path containing Perl module.
@@ -60,7 +60,7 @@ _
 }, {}];
 
 1;
-# ABSTRACT: Filename of perl module, e.g. /path/Foo.pm
+# ABSTRACT: A .pm filename, e.g. /path/Foo.pm
 
 __END__
 
@@ -70,11 +70,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::perl::pm_filename - Filename of perl module, e.g. /path/Foo.pm
+Sah::Schema::perl::pm_filename - A .pm filename, e.g. /path/Foo.pm
 
 =head1 VERSION
 
-This document describes version 0.029 of Sah::Schema::perl::pm_filename (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
+This document describes version 0.030 of Sah::Schema::perl::pm_filename (from Perl distribution Sah-Schemas-Perl), released on 2020-05-08.
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
